@@ -253,9 +253,12 @@ gail_canvas_text_get_character_at_offset (AtkText *text,
   gchar *index;
   gunichar unichar;
 
-  g_return_val_if_fail (GAIL_IS_CANVAS_TEXT (text), 0);
+  g_return_val_if_fail (GAIL_IS_CANVAS_TEXT (text), '\0');
   gail_item = GAIL_CANVAS_TEXT (text);
   buffer = gail_item->textutil->buffer;
+  if (offset >= gtk_text_buffer_get_char_count (buffer))
+    return '\0';
+
   gtk_text_buffer_get_start_iter (buffer, &start);
   gtk_text_buffer_get_end_iter (buffer, &end);
   string = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
