@@ -125,7 +125,7 @@ gail_container_get_n_children (AtkObject* obj)
 
   widget = GTK_ACCESSIBLE (obj)->widget;
   if (widget == NULL)
-    return count;
+    return 0;
 
   children = gtk_container_get_children (GTK_CONTAINER(widget));
   count = g_list_length (children);
@@ -220,7 +220,7 @@ gail_container_real_remove_gtk (GtkContainer       *container,
                                 GtkWidget          *widget,
                                 gpointer           data)
 {
-  AtkPropertyValues values = { 0, };
+  AtkPropertyValues values = { NULL };
   AtkObject* atk_parent;
   AtkObject *atk_child;
   GailContainer *gail_container;
@@ -245,8 +245,9 @@ gail_container_real_remove_gtk (GtkContainer       *container,
   index = g_list_index (gail_container->children, widget);
   g_list_free (gail_container->children);
   gail_container->children = gtk_container_get_children (container);
-  g_signal_emit_by_name (atk_parent, "children_changed::remove", 
-                         index, atk_child, NULL);
+  if (index >= 0 && index <= g_list_length (gail_container->children))
+    g_signal_emit_by_name (atk_parent, "children_changed::remove", 
+			   index, atk_child, NULL);
 
   return 1;
 }
