@@ -21,6 +21,7 @@
 #include "gailradiobutton.h"
 
 static void      gail_radio_button_class_init        (GailRadioButtonClass *klass);
+static void      gail_radio_button_instance_init     (GailRadioButton      *radio_button);
 
 static AtkRelationSet* gail_radio_button_ref_relation_set (AtkObject       *obj)
 ;
@@ -44,7 +45,7 @@ gail_radio_button_get_type (void)
       NULL, /* class data */
       sizeof (GailRadioButton), /* instance size */
       0, /* nb preallocs */
-      (GInstanceInitFunc) NULL, /* instance init */
+      (GInstanceInitFunc) gail_radio_button_instance_init, /* instance init */
       NULL /* value table */
     };
 
@@ -82,12 +83,19 @@ gail_radio_button_new (GtkWidget *widget)
   return accessible;
 }
 
+static void
+gail_radio_button_instance_init (GailRadioButton *radio_button)
+{
+  radio_button->old_group = NULL;
+}
+
 AtkRelationSet*
 gail_radio_button_ref_relation_set (AtkObject *obj)
 {
   GtkWidget *widget;
   AtkRelationSet *relation_set;
   GSList *list;
+  GailRadioButton *radio_button;
 
   g_return_val_if_fail (GAIL_IS_RADIO_BUTTON (obj), NULL);
 
@@ -99,16 +107,30 @@ gail_radio_button_ref_relation_set (AtkObject *obj)
      */
     return NULL;
   }
+  radio_button = GAIL_RADIO_BUTTON (obj);
 
   relation_set = ATK_OBJECT_CLASS (parent_class)->ref_relation_set (obj);
 
+  /*
+   * If the radio button'group has changed remove the relation
+   */
+  list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
+  
+  if (radio_button->old_group != list)
+    {
+      AtkRelation *relation;
+
+      relation = atk_relation_set_get_relation_by_type (relation_set, ATK_RELATION_MEMBER_OF);
+      atk_relation_set_remove (relation_set, relation);
+    }
+
   if (!atk_relation_set_contains (relation_set, ATK_RELATION_MEMBER_OF))
   {
     /*
      * Get the members of the button group
      */
-    list = gtk_radio_button_get_group (GTK_RADIO_BUTTON (widget));
 
+    radio_button->old_group = list;
     if (list)
     {
       AtkObject **accessible_array;
@@ -129,6 +151,8 @@ gail_radio_button_ref_relation_set (AtkObject *obj)
       }
       relation = atk_relation_new (accessible_array, list_length,
                                    ATK_RELATION_MEMBER_OF);
+      g_free (accessible_array);
+
       atk_relation_set_add (relation_set, relation);
       /*
        * Unref the relation so that it is not leaked.
